summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/model_utils.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/model_utils.h')
-rw-r--r--umbrello/umbrello/model_utils.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/umbrello/umbrello/model_utils.h b/umbrello/umbrello/model_utils.h
index 771d6f86..600e841c 100644
--- a/umbrello/umbrello/model_utils.h
+++ b/umbrello/umbrello/model_utils.h
@@ -75,13 +75,13 @@ UMLObject* findUMLObject( const UMLObjectList& inList,
* if the default name is taken e.g. new_actor, new_actor_1
* etc.
* @param type The object type.
* @param tqparentPkg The package in which to compare the name.
* @param prefix The prefix to use (optional.)
* If no prefix is given then a type related
* prefix will be chosen internally.
*/
TQString uniqObjectName(Uml::Object_Type type,
- UMLPackage *tqparentPkg,
+ UMLPackage *parentPkg,
TQString prefix = TQString());
/**
@@ -75,13 +75,13 @@ UMLObject* findUMLObject( const UMLObjectList& inList,
* etc.
* @param type The object type.
- * @param tqparentPkg The package in which to compare the name.
+ * @param parentPkg The package in which to compare the name.
* @param prefix The prefix to use (optional.)
* If no prefix is given then a type related